@@ -32,6 +32,9 @@ from cpref import make_ref
 
 from cpmel.exc import *
 
+_ptr = long if sys.version_info.major == 2 else int
+_any_int = (int, long) if sys.version_info.major == 2 else int
+
 
 class BaseType(object):
     __slots__ = ('ref',)
@@ -69,6 +72,9 @@ class Node(BaseType):
             return hash(self) == hash(other)
         return False
 
+    def __ne__(self, other):
+        return not self == other
+
     def __str__(self):
         return self.name()
 
@@ -278,6 +284,9 @@ class Attr(BaseType):
             return hash(self) == hash(other)
         return False
 
+    def __ne__(self, other):
+        return not self == other
+
     def __lshift__(self, other):
         a = arg_conv(self)
         b = arg_conv(other)
@@ -299,6 +308,15 @@ class Attr(BaseType):
         except CPMelException:
             raise AttributeError("{} object has no attribute '{}'".format(self.__class__.__name__, item))
 
+    def __getitem__(self, item):
+        try:
+            if isinstance(item, _any_int):
+                return new_object("{}[{}]".format(self.name(), item))
+            else:
+                raise TypeError('attribute indices must be integers, not {}'.format(item.__class__.__name__))
+        except CPMelException:
+            raise AttributeError("{} object has no item '{}'".format(self.__class__.__name__, item))
+
     def api1_m_plug(self):
         self.assert_valid()
 
@@ -391,6 +409,9 @@ class Component(BaseType):
             return hash(self) == hash(other)
         return False
 
+    def __ne__(self, other):
+        return not self == other
+
     def api1_m_component(self):
         self.assert_valid()
 
@@ -433,9 +454,6 @@ class Component(BaseType):
         return (new_object(i) for i in mc.ls(self.__melobject__(), fl=True))
 
 
-_ptr = long if sys.version_info.major == 2 else int
-
-
 class UI(object):
     __slots__ = ('ui',)
 
@@ -450,6 +468,9 @@ class UI(object):
             return hash(self) == hash(other)
         return False
 
+    def __ne__(self, other):
+        return not self == other
+
     def get_widget(self):
         u"""
         :return:
